|PyPI| |anaconda| |RTFD| |CircleCI| |AppVeyor| |codecov|

pyswashes is a python library that generates analytic solutions to the
Shallow Water Equations

The code is hosted on `GitHub <https://github.com/lrntct/pyswashes>`_.
For more information, please see the `documentation <https://pyswashes.readthedocs.io>`_.

.. |PyPI| image:: https://badge.fury.io/py/pyswashes.svg
   :target: https://pypi.python.org/pypi/pyswashes
   :alt: PyPI version
.. |anaconda| image:: https://anaconda.org/lrntct/swashes/badges/installer/conda.svg
   :target: https://anaconda.org/lrntct/pyswashes
   :alt: Install with Anaconda
.. |CircleCI| image:: https://circleci.com/gh/lrntct/pyswashes.svg?style=svg
   :target: https://circleci.com/gh/lrntct/pyswashes
   :alt: CircleCI status
.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/github/lrntct/pyswashes?branch=master&svg=true
   :target: https://ci.appveyor.com/project/lrntct/pyswashes
   :alt: AppVeyor status
.. |codecov| image:: https://codecov.io/gh/lrntct/pyswashes/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/lrntct/pyswashes
   :alt: code coverage
.. |RTFD| image:: https://readthedocs.org/projects/pyswashes/badge/?version=latest
   :target: http://pyswashes.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
